/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.mongodb.hook.listeners;

import com.liferay.mongodb.lang.MongoOperator;
import com.liferay.mongodb.util.MongoDBUtil;
import com.liferay.portal.ModelListenerException;
import com.liferay.portal.model.BaseModelListener;
import com.liferay.portlet.expando.model.ExpandoColumn;
import com.liferay.portlet.expando.model.ExpandoTable;
import com.liferay.portlet.expando.service.ExpandoTableLocalServiceUtil;

import com.mongodb.BasicDBObject;
import com.mongodb.DBCollection;
import com.mongodb.DBObject;

/**
 * @author Raymond Augé
 * @author Brian Wing Shun Chan
 */
public class ExpandoColumnListener extends BaseModelListener<ExpandoColumn> {

	@Override
	public void onAfterRemove(ExpandoColumn expandoColumn)
		throws ModelListenerException {

		try {
			doOnAfterRemove(expandoColumn);
		}
		catch (Exception e) {
			throw new ModelListenerException(e);
		}
	}

	protected void doOnAfterRemove(ExpandoColumn expandoColumn)
		throws Exception {

		ExpandoTable expandoTable = ExpandoTableLocalServiceUtil.getTable(
			expandoColumn.getTableId());

		DBCollection dbCollection = MongoDBUtil.getCollection(expandoTable);

		for (DBObject indexDBObject : dbCollection.getIndexInfo()) {
			DBObject keyDBObject = (DBObject)indexDBObject.get("key");

			if (keyDBObject.containsField(expandoColumn.getName())) {
				dbCollection.dropIndex(keyDBObject);
			}
		}

		DBObject operatorDBObject = new BasicDBObject(
			MongoOperator.UNSET, new BasicDBObject(expandoColumn.getName(), 1));

		dbCollection.update(new BasicDBObject(), operatorDBObject, false, true);
	}

}