/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.mongodb.hook.listeners;

import com.liferay.mongodb.util.MongoDBUtil;
import com.liferay.portal.model.BaseModelListener;
import com.liferay.portlet.expando.model.ExpandoTable;

import com.mongodb.BasicDBObject;
import com.mongodb.DB;
import com.mongodb.DBCollection;

/**
 * @author Raymond Augé
 * @author Brian Wing Shun Chan
 */
public class ExpandoTableListener extends BaseModelListener<ExpandoTable> {

	@Override
	public void onAfterCreate(ExpandoTable expandoTable) {
		DB db = MongoDBUtil.getDB(expandoTable.getCompanyId());

		String collectionName = MongoDBUtil.getCollectionName(
			expandoTable.getClassName(), expandoTable.getName());

		if (!db.collectionExists(collectionName)) {
			DBCollection dbCollection = db.createCollection(
				collectionName, null);

			dbCollection.createIndex(new BasicDBObject("valueId", 1));
			dbCollection.createIndex(new BasicDBObject("companyId", 1));
			dbCollection.createIndex(new BasicDBObject("tableId", 1));
			dbCollection.createIndex(new BasicDBObject("rowId", 1));
			dbCollection.createIndex(new BasicDBObject("classNameId", 1));
			dbCollection.createIndex(new BasicDBObject("classPK", 1));
		}
	}

	@Override
	public void onAfterRemove(ExpandoTable expandoTable) {
		DB db = MongoDBUtil.getDB(expandoTable.getCompanyId());

		String tableName = MongoDBUtil.getCollectionName(
			expandoTable.getClassName(), expandoTable.getName());

		if (db.collectionExists(tableName)) {
			DBCollection dbCollection = db.getCollection(tableName);

			dbCollection.drop();
		}
	}

}