/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.mongodb.hook.service.impl;

import com.liferay.mongodb.lang.MongoOperator;
import com.liferay.mongodb.util.MongoDBUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.UnicodeProperties;
import com.liferay.portlet.expando.model.ExpandoColumn;
import com.liferay.portlet.expando.model.ExpandoColumnConstants;
import com.liferay.portlet.expando.model.ExpandoTable;
import com.liferay.portlet.expando.service.ExpandoColumnLocalService;
import com.liferay.portlet.expando.service.ExpandoColumnLocalServiceWrapper;
import com.liferay.portlet.expando.service.ExpandoTableLocalServiceUtil;

import com.mongodb.BasicDBObject;
import com.mongodb.DBCollection;
import com.mongodb.DBObject;

/**
 * @author Raymond Augé
 * @author Brian Wing Shun Chan
 */
public class MongoExpandoColumnLocalServiceImpl
	extends ExpandoColumnLocalServiceWrapper {

	public MongoExpandoColumnLocalServiceImpl(
		ExpandoColumnLocalService expandoColumnLocalService) {

		super(expandoColumnLocalService);
	}

	@Override
	public ExpandoColumn updateColumn(
			long columnId, String name, int type, Object defaultData)
		throws PortalException, SystemException {

		ExpandoColumn expandoColumn = super.updateColumn(
			columnId, name, type, defaultData);

		ExpandoTable expandoTable = ExpandoTableLocalServiceUtil.getTable(
			expandoColumn.getTableId());

		DBCollection dbCollection = MongoDBUtil.getCollection(expandoTable);

		DBObject operatorDBObject = new BasicDBObject(
			MongoOperator.RENAME,
			new BasicDBObject(expandoColumn.getName(), name));

		dbCollection.update(new BasicDBObject(), operatorDBObject);

		return expandoColumn;
	}

	@Override
	public ExpandoColumn updateTypeSettings(long columnId, String typeSettings)
		throws PortalException, SystemException {

		ExpandoColumn expandoColumn = super.updateTypeSettings(
			columnId, typeSettings);

		ExpandoTable expandoTable = ExpandoTableLocalServiceUtil.getTable(
			expandoColumn.getTableId());

		UnicodeProperties typeSettingsProperties =
			expandoColumn.getTypeSettingsProperties();

		int indexType = GetterUtil.getInteger(
			typeSettingsProperties.getProperty(
				ExpandoColumnConstants.INDEX_TYPE));

		if (indexType != ExpandoColumnConstants.INDEX_TYPE_NONE) {
			DBCollection dbCollection = MongoDBUtil.getCollection(expandoTable);

			dbCollection.createIndex(
				new BasicDBObject(expandoColumn.getName(), 1));
		}

		return expandoColumn;
	}

}