/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.mongodb.hook.service.impl;

import com.liferay.mongodb.util.MongoDBUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portlet.expando.DuplicateTableNameException;
import com.liferay.portlet.expando.model.ExpandoTable;
import com.liferay.portlet.expando.service.ExpandoTableLocalService;
import com.liferay.portlet.expando.service.ExpandoTableLocalServiceWrapper;

import com.mongodb.DB;
import com.mongodb.DBCollection;

/**
 * @author Raymond Augé
 * @author Brian Wing Shun Chan
 */
public class MongoExpandoTableLocalServiceImpl
	extends ExpandoTableLocalServiceWrapper {

	public MongoExpandoTableLocalServiceImpl(
		ExpandoTableLocalService expandoTableLocalService) {

		super(expandoTableLocalService);
	}

	@Override
	public ExpandoTable updateTable(long tableId, String name)
		throws PortalException, SystemException {

		ExpandoTable expandoTable = super.getTable(tableId);

		DB db = MongoDBUtil.getDB(expandoTable.getCompanyId());

		String collectionName = MongoDBUtil.getCollectionName(
			expandoTable.getClassName(), expandoTable.getName());
		String newCollectionName = MongoDBUtil.getCollectionName(
			expandoTable.getClassName(), name);

		if (db.collectionExists(newCollectionName)) {
			throw new DuplicateTableNameException(name);
		}

		expandoTable = super.updateTable(tableId, name);

		if (db.collectionExists(collectionName)) {
			DBCollection dbCollection = db.getCollection(collectionName);

			dbCollection.rename(newCollectionName);
		}
		else {
			db.createCollection(newCollectionName, null);
		}

		return expandoTable;
	}

}